@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include "filteractionwithstringlist.h"
 #include <Akonadi/KMime/MessageStatus>
 
-namespace MailCommon {
+namespace MailCommon
+{
 class FilterActionStatus : public FilterActionWithStringList
 {
     Q_OBJECT
