@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -49,15 +49,12 @@ void KMFilterAccountList::updateAccountList(MailCommon::MailFilter *filter)
     const int nbAccount = lst.count();
     for (int i = 0; i < nbAccount; ++i) {
         const Akonadi::AgentInstance agent = lst.at(i);
-        auto *listItem = new QTreeWidgetItem(this, top);
+        auto listItem = new QTreeWidgetItem(this, top);
         listItem->setText(0, agent.name());
         listItem->setText(1, agent.type().name());
         listItem->setText(2, agent.identifier());
         if (filter) {
-            listItem->setCheckState(0,
-                                    filter->applyOnAccount(agent.identifier())
-                                    ? Qt::Checked
-                                    : Qt::Unchecked);
+            listItem->setCheckState(0, filter->applyOnAccount(agent.identifier()) ? Qt::Checked : Qt::Unchecked);
         }
         top = listItem;
     }
@@ -98,12 +95,11 @@ void KMFilterAccountList::applyOnAccount(const QStringList &lstAccount)
     const int nbAccount = lst.count();
     for (int i = 0; i < nbAccount; ++i) {
         const Akonadi::AgentInstance agent = lst.at(i);
-        auto *listItem = new QTreeWidgetItem(this, top);
+        auto listItem = new QTreeWidgetItem(this, top);
         listItem->setText(0, agent.name());
         listItem->setText(1, agent.type().name());
         listItem->setText(2, agent.identifier());
-        listItem->setCheckState(0, lstAccount.contains(agent.identifier())
-                                ? Qt::Checked : Qt::Unchecked);
+        listItem->setCheckState(0, lstAccount.contains(agent.identifier()) ? Qt::Checked : Qt::Unchecked);
         top = listItem;
     }
     blockSignals(false);
